module.exports = defineTest({
	description: 'deconflict default exported named function and class expressions'
});
